"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.resetLimitsForTesting = exports.getBufferSize = exports.getJsonIndent = exports.queryAll = exports.queryNamespaces = exports.stringify = exports.calculatePercentage = void 0;
const core_bundle_1 = require("@salesforce/core-bundle");
const DEFAULT_BUFFER_SIZE = 256;
const MIN_BUFFER_SIZE = 256;
const MAX_BUFFER_SIZE = 32_768;
const DEFAULT_JSON_INDENT = undefined;
const MIN_JSON_INDENT = 0;
const MAX_JSON_INDENT = 8;
let jsonIndent = null;
let bufferSize = null;
function calculatePercentage(dividend, divisor) {
    let percentage = '0%';
    if (dividend > 0) {
        const calcPct = ((dividend / divisor) * 100).toFixed();
        percentage = `${calcPct}%`;
    }
    return percentage;
}
exports.calculatePercentage = calculatePercentage;
function stringify(jsonObj) {
    return JSON.stringify(jsonObj, null, 2);
}
exports.stringify = stringify;
async function queryNamespaces(connection) {
    const installedNsQuery = 'SELECT NamespacePrefix FROM PackageLicense';
    const installedNsPromise = connection.query(installedNsQuery);
    const orgNsQuery = 'SELECT NamespacePrefix FROM Organization';
    const orgNsPromise = connection.query(orgNsQuery);
    const allNamespaces = await Promise.all([installedNsPromise, orgNsPromise]);
    const installedNamespaces = allNamespaces[0].records.map((record) => {
        return { installedNs: true, namespace: record.NamespacePrefix };
    });
    const orgNamespaces = allNamespaces[1].records.map((record) => {
        return { installedNs: false, namespace: record.NamespacePrefix };
    });
    return [...orgNamespaces, ...installedNamespaces];
}
exports.queryNamespaces = queryNamespaces;
const queryAll = async (connection, query, tooling = false) => {
    const conn = tooling ? connection.tooling : connection;
    const allRecords = [];
    let result = await conn.query(query);
    allRecords.push(...result.records);
    while (!result.done) {
        result = (await conn.queryMore(result.nextRecordsUrl));
        allRecords.push(...result.records);
    }
    return {
        done: true,
        totalSize: allRecords.length,
        records: allRecords
    };
};
exports.queryAll = queryAll;
const getJsonIndent = () => {
    if (jsonIndent !== null) {
        return jsonIndent;
    }
    let jsonIndentNum = DEFAULT_JSON_INDENT;
    const envJsonIndent = process.env.SF_APEX_RESULTS_JSON_INDENT;
    if (envJsonIndent && Number.isInteger(Number(envJsonIndent))) {
        jsonIndentNum = Number(envJsonIndent);
    }
    if (jsonIndentNum < MIN_JSON_INDENT || jsonIndentNum > MAX_JSON_INDENT) {
        const logger = core_bundle_1.Logger.childFromRoot('utils');
        logger.warn(`Json indent ${jsonIndentNum} is outside of the valid range (${MIN_JSON_INDENT}-${MAX_JSON_INDENT}). Using default json indent of ${DEFAULT_JSON_INDENT}.`);
        jsonIndentNum = DEFAULT_JSON_INDENT;
    }
    jsonIndent = jsonIndentNum;
    return jsonIndent;
};
exports.getJsonIndent = getJsonIndent;
const getBufferSize = () => {
    if (bufferSize !== null) {
        return bufferSize;
    }
    let bufferSizeNum = DEFAULT_BUFFER_SIZE;
    const jsonBufferSize = process.env.SF_APEX_JSON_BUFFER_SIZE;
    if (jsonBufferSize && Number.isInteger(Number(jsonBufferSize))) {
        bufferSizeNum = Number(jsonBufferSize);
    }
    if (bufferSizeNum < MIN_BUFFER_SIZE || bufferSizeNum > MAX_BUFFER_SIZE) {
        const logger = core_bundle_1.Logger.childFromRoot('utils');
        logger.warn(`Buffer size ${bufferSizeNum} is outside of the valid range (${MIN_BUFFER_SIZE}-${MAX_BUFFER_SIZE}). Using default buffer size of ${DEFAULT_BUFFER_SIZE}.`);
        bufferSizeNum = DEFAULT_BUFFER_SIZE;
    }
    bufferSize = bufferSizeNum;
    JSON.stringify(bufferSize);
    return bufferSize;
};
exports.getBufferSize = getBufferSize;
// exported for testing
const resetLimitsForTesting = () => {
    bufferSize = null;
    jsonIndent = null;
};
exports.resetLimitsForTesting = resetLimitsForTesting;
//# sourceMappingURL=utils.js.map